BaseChart<D> class abstract

Base class for all charts.

This class provides the foundation for building various types of charts with different configurations and behaviors.

Inheritance
Implementers
Annotations

Constructors

BaseChart(List<Series<dynamic, D>> seriesList, {Key? key, bool? animate, Duration? animationDuration, SeriesRendererConfig<D>? defaultRenderer, List<SeriesRendererConfig<D>>? customSeriesRenderers, List<ChartBehavior<D>>? behaviors, List<SelectionModelConfig<D>>? selectionModels, RTLSpec? rtlSpec, bool defaultInteractions = true, LayoutConfig? layoutConfig, UserManagedState<D>? userManagedState})
const

Properties

animate → bool
Animation transitions.
final
animationDuration → Duration
The duration of the animation when data changes.
final
behaviors → List<ChartBehavior<D>>?
List of chart behaviors to apply to the chart.
final
customSeriesRenderers → List<SeriesRendererConfig<D>>?
final
defaultInteractions → bool
Include the default interactions or not.
final
defaultRenderer → SeriesRendererConfig<D>?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutConfig → LayoutConfig?
Used to configure the margin sizes around the drawArea that the axis and other things render into.
final
rtlSpec → RTLSpec?
The spec to use if RTL is enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionModels → List<SelectionModelConfig<D>>?
List of selection models to add to the chart.
final
seriesList → List<Series<dynamic, D>>
Series list to draw.
final
userManagedState → UserManagedState<D>?
Optional state that overrides internally kept state, such as selection.
final

Methods

addDefaultInteractions(List<ChartBehavior> behaviors) → void
Create the list of default interaction behaviors.
createCommonChart(BaseChartState<D> chartState) → BaseChart<D>
Creates and returns a common.BaseChart.
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → BaseChartState<D>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDesiredGestures(BaseChartState chartState) → Set<GestureType>
Gets distinct set of gestures this chart will subscribe to.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateCommonChart(BaseChart<D> chart, BaseChart<D>? oldWidget, BaseChartState<D> chartState) → void
Updates the common.BaseChart based on changes in the widget properties.

Operators

operator ==(Object other) → bool
The equality operator.
inherited