BasicNumericTickProviderSpec class

Implemented types
Annotations

Constructors

BasicNumericTickProviderSpec({bool? zeroBound, bool? dataIsInWholeNumbers, int? desiredTickCount, int? desiredMinTickCount, int? desiredMaxTickCount})
Creates a TickProviderSpec that dynamically chooses the number of ticks based on the extents of the data.
const

Properties

dataIsInWholeNumbers → bool?
final
desiredMaxTickCount → int?
final
desiredMinTickCount → int?
final
desiredTickCount → int?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zeroBound → bool?
final

Methods

createTickProvider(ChartContext context) → NumericTickProvider
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override