ColorUtil class

Utility class for converting between common and Flutter colors.

Constructors

ColorUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromDartColor(Color color) → Color
Converts a Flutter color to a common color.
toDartColor(Color color) → Color
Converts a common color to a Flutter color.