LayoutConfig class

Configuration for the chart layout.

Annotations

Constructors

LayoutConfig({required MarginSpec leftMarginSpec, required MarginSpec topMarginSpec, required MarginSpec rightMarginSpec, required MarginSpec bottomMarginSpec})
const

Properties

bottomMarginSpec → MarginSpec
Margin specification for the bottom side of the chart.
final
commonLayoutConfig → LayoutConfig
Converts the layout configuration to the common common.LayoutConfig.
no setter
hashCode → int
The hash code for this object.
no setterinherited
leftMarginSpec → MarginSpec
Margin specification for the left side of the chart.
final
rightMarginSpec → MarginSpec
Margin specification for the right side of the chart.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topMarginSpec → MarginSpec
Margin specification for the top side of the chart.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited