LineStyleSpec class

Annotations

Constructors

LineStyleSpec({Color? color, List<int>? dashPattern, int? thickness})
const

Properties

color → Color?
final
dashPattern → List<int>?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override