NumericExtents class

Represents the starting and ending extent of a dataset.

Constructors

NumericExtents(num min, num max)
Precondition: min <= max.
const
NumericExtents.fromValues(Iterable<num> values)
Returns Extents based on the min and max of the given values. Returns NumericExtents.empty if values are empty
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
max → num
final
min → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num
no setter

Methods

compareValue(num value) → int
Compares the given value against the extents.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(NumericExtents other) → bool
plus(NumericExtents other) → NumericExtents
Returns the union of this and other.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

empty → const NumericExtents
unbounded → const NumericExtents