OrdinalCartesianChart class

Inheritance

Constructors

OrdinalCartesianChart({bool? vertical, LayoutConfig? layoutConfig, NumericAxis? primaryMeasureAxis, NumericAxis? secondaryMeasureAxis, LinkedHashMap<String, NumericAxis>? disjointMeasureAxes})

Properties

animatingThisDraw → bool
no setterinherited
animationPercent ↔ double
A value in the range [0.0, 1.0] that indicates the animation progress.
getter/setter pairinherited
behaviors → List<ChartBehavior<String>>
Returns a list of behaviors that have been added.
no setterinherited
chartHeight → int?
no setterinherited
chartIsDirty → bool
If the chart configuration has changed and requires a redraw.
no setterinherited
chartWidth → int?
no setterinherited
context ↔ ChartContext
getter/setter pairinherited
currentSeriesList → List<MutableSeries<String>>
no setterinherited
defaultRenderer ↔ SeriesRenderer<String>
getter/setter pairinherited
disjointMeasureAxisSpecs ← LinkedHashMap<String, NumericAxisSpec>?
Sets a map of disjoint measure axes for the chart.
no getterinherited
domainAxis → Axis<String>?
no setterinherited
domainAxisSpec ← AxisSpec<String>
Create a new domain axis and save the new spec to be applied during configurationChanged.
no getterinherited
drawableLayoutAreaBounds → Rectangle<int>
Returns the combined bounds of the chart draw area and all layout components that draw series data.
no setterinherited
drawAreaBounds → Rectangle<int>
Returns the bounds of the chart draw area.
no setterinherited
flipVerticalAxisOutput ↔ bool
If set to true, the vertical axis will render the opposite of the default direction.
getter/setter pairinherited
gestureProxy → ProxyGestureListener
no setterinherited
graphicsFactory ↔ GraphicsFactory?
Internal use only.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isTappable → bool
Whether or not the chart will respond to tap events.
no setterinherited
marginBottom → int
no setterinherited
marginLeft → int
no setterinherited
marginRight → int
no setterinherited
marginTop → int
no setterinherited
primaryMeasureAxisSpec ← NumericAxisSpec?
Sets the primary measure axis for the chart, rendered on the start side of the domain axis.
no getterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryMeasureAxisSpec ← NumericAxisSpec?
Sets the secondary measure axis for the chart, rendered on the end side of the domain axis.
no getterinherited
selectExactEventLocation → bool
Whether selected data should be restricted to only have points that cover this event location.
no setterinherited
selectNearestByDomain → bool
Whether data should be selected by nearest domain distance, or by relative distance.
no setterinherited
selectOverlappingPoints → bool
Whether data should be expanded by to include all points overlapping the selection point
no setterinherited
transition ↔ Duration
getter/setter pairinherited
vertical ↔ bool
getter/setter pairinherited

Methods

addBehavior(ChartBehavior<String> behavior) → void
Attaches a behavior to the chart.
inherited
addGestureListener(GestureListener listener) → GestureListener
Add a GestureListener to this chart.
inherited
addLifecycleListener(LifecycleListener<String> listener) → LifecycleListener<String>
inherited
addSeriesRenderer(SeriesRenderer<String> renderer) → void
inherited
addView(LayoutView view) → void
inherited
configurationChanged() → void
Finish configuring components that require context and graphics factory.
inherited
configureSeries(List<MutableSeries<String>> seriesList) → void
Preprocess series to assign missing color functions.
inherited
createBehavior(BehaviorCreator creator) → ChartBehavior<String>
Helper method to create a behavior with congruent types.
inherited
createDomainAxisFromSpec(AxisSpec<String> axisSpec) → Axis<String>?
Creates the domain axis from a provided axis spec.
inherited
destroy() → void
Called to free up any resources due to chart going away.
inherited
draw(List<Series<dynamic, String>> seriesList) → void
inherited
drawInternal(List<MutableSeries<String>> seriesList, {bool? skipAnimation, bool? skipLayout}) → void
inherited
fireOnAnimationComplete() → void
inherited
fireOnAxisConfigured() → void
inherited
fireOnDraw(List<MutableSeries<String>> seriesList) → void
inherited
fireOnPostprocess(List<MutableSeries<String>> seriesList) → void
inherited
fireOnPostrender(ChartCanvas canvas) → void
inherited
fireOnPreprocess(List<MutableSeries<String>> seriesList) → void
inherited
getAllDatumDetails({bool includeOverlaySeries = false}) → List<DatumDetails<String>>
Retrieves the datum details for all data on the chart.
inherited
getDatumDetails(SelectionModelType type) → List<DatumDetails<String>>
Returns a list of datum details from selection model of type.
inherited
getMeasureAxis({String? axisId}) → NumericAxis
Gets the measure axis matching the provided id.
inherited
getNearestDatumDetailPerSeries(Point<double> drawAreaPoint, bool selectAcrossAllDrawAreaComponents) → List<DatumDetails<String>>
Retrieves the datum details that are nearest to the given drawAreaPoint.
inherited
getSelectedDatumDetails(SelectionModelType selectionModelType) → List<DatumDetails<String>>
Retrieves the datum details for the current chart selection.
inherited
getSelectionModel(SelectionModelType type) → MutableSelectionModel<String>
Returns MutableSelectionModel for the given type. Lazy creates one upon first request.
inherited
getSeriesRenderer(String? rendererId) → SeriesRenderer<String>
inherited
init(ChartContext context, GraphicsFactory graphicsFactory) → void
inherited
initDomainAxis() → void
Allows the chart to configure the domain axis when it is created.
override
layout(int width, int height) → void
inherited
layoutInternal(int width, int height) → void
inherited
makeDefaultRenderer() → SeriesRenderer<String>
inherited
makeSeries(Series<dynamic, String> series) → MutableSeries<String>
inherited
markChartDirty() → void
Marks the chart as dirty.
inherited
measure(int width, int height) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPostLayout(Map<String, List<MutableSeries<String>>> rendererToSeriesList) → void
inherited
onSkipLayout() → void
inherited
paint(ChartCanvas canvas) → void
inherited
pointWithinRenderer(Point<double> chartPosition) → bool
inherited
preprocessSeries(List<MutableSeries<String>> seriesList) → Map<String, List<MutableSeries<String>>>
Preprocess series to allow stacking and other mutations.
inherited
redraw({bool skipAnimation = false, bool skipLayout = false}) → void
Redraws and re-lays-out the chart using the previously rendered layout dimensions.
inherited
registerTappable(ChartBehavior<String> behavior) → void
Tells the chart that this behavior responds to tap events.
inherited
removeBehavior(ChartBehavior<String>? behavior) → bool
Removes a behavior from the chart.
inherited
removeGestureListener(GestureListener listener) → void
Remove a GestureListener from this chart.
inherited
removeLifecycleListener(LifecycleListener<String> listener) → bool
inherited
removeView(LayoutView view) → void
inherited
resetChartDirtyFlag() → void
Resets the chart dirty flag to false.
inherited
toString() → String
A string representation of this object.
inherited
unregisterTappable(ChartBehavior<String> behavior) → void
Tells the chart that this behavior no longer responds to tap events.
inherited
updateConfig(LayoutConfig? layoutConfig) → void
Updates the layout configuration used inside the layout manager.
inherited
withinDrawArea(Point<num> point) → bool
Returns whether or not point is within the draw area bounds.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited