TimeFormatterSpec class

Formatters for a single level of the DateTimeTickFormatterSpec.

Annotations

Constructors

TimeFormatterSpec({String? format, String? transitionFormat, String? noonFormat})
Creates a formatter for a particular granularity of data.
const

Properties

format → String?
final
hashCode → int
The hash code for this object.
no setteroverride
noonFormat → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionFormat → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override